@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,11 +12,10 @@
 #
 ##############################################################################
 """Test fields.
-
-$Id: test_fields.py 103270 2009-08-27 13:56:02Z nadako $
 """
 import unittest
-from zope.testing import cleanup, doctest
+import doctest
+from zope.testing import cleanup
 
 def test_suite():
     return unittest.TestSuite((
