@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,17 +12,17 @@
 #
 ##############################################################################
 """Browser Menu Item Tests
-
-$Id: test_menu.py 103270 2009-08-27 13:56:02Z nadako $
 """
 import unittest
-from zope.testing import doctest, cleanup, doctestunit
+import doctest
+import pprint
+from zope.testing import cleanup
 
 def test_suite():
     return unittest.TestSuite((
         doctest.DocFileSuite('../README.txt',
                              setUp=lambda test:cleanup.setUp(),
                              tearDown=lambda test:cleanup.tearDown(),
-                             globs={'pprint': doctestunit.pprint},
+                             globs={'pprint': pprint.pprint},
                              optionflags=doctest.NORMALIZE_WHITESPACE),
         ))
